==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncObjectPatchBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SyncObjectPatchBuilder extends io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluentImpl<io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch,io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchBuilder>{
  public SyncObjectPatchBuilder() {
    this(false);
  }
  public SyncObjectPatchBuilder(java.lang.Boolean validationEnabled) {
    this(new SyncObjectPatch(), validationEnabled);
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SyncObjectPatch(), validationEnabled);
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch instance) {
    this(fluent, instance, false);
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPatch(instance.getPatch()); 
    fluent.withPatchType(instance.getPatchType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch instance) {
    this(instance,false);
  }
  public SyncObjectPatchBuilder(io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPatch(instance.getPatch()); 
    this.withPatchType(instance.getPatchType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SyncObjectPatchFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SyncObjectPatch build() {
    SyncObjectPatch buildable = new SyncObjectPatch(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getPatch(),fluent.getPatchType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyncObjectPatchBuilder that = (SyncObjectPatchBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.6.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncObjectPatchBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SyncObjectPatchBuilder extends SyncObjectPatchFluentImpl<SyncObjectPatchBuilder> implements VisitableBuilder<SyncObjectPatch,SyncObjectPatchBuilder>{
  public SyncObjectPatchBuilder() {
    this(false);
  }
  public SyncObjectPatchBuilder(Boolean validationEnabled) {
    this(new SyncObjectPatch(), validationEnabled);
  }
  public SyncObjectPatchBuilder(SyncObjectPatchFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncObjectPatchBuilder(SyncObjectPatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SyncObjectPatch(), validationEnabled);
  }
  public SyncObjectPatchBuilder(SyncObjectPatchFluent<?> fluent,SyncObjectPatch instance) {
    this(fluent, instance, false);
  }
  public SyncObjectPatchBuilder(SyncObjectPatchFluent<?> fluent,SyncObjectPatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPatch(instance.getPatch()); 
    fluent.withPatchType(instance.getPatchType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncObjectPatchBuilder(SyncObjectPatch instance) {
    this(instance,false);
  }
  public SyncObjectPatchBuilder(SyncObjectPatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPatch(instance.getPatch()); 
    this.withPatchType(instance.getPatchType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SyncObjectPatchFluent<?> fluent;
  Boolean validationEnabled;
  public SyncObjectPatch build() {
    SyncObjectPatch buildable = new SyncObjectPatch(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getPatch(),fluent.getPatchType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
